@@ -6,10 +6,9 @@ is a collections of CSVDataclass objects.
 import logging
 import operator
 import os
-from typing import Generic, Iterable, List, Tuple, TypeVar, Union
+from typing import Generic, Iterable, List, Tuple, TypeVar
 
 import pathvalidate
-from tabulate import tabulate
 
 from . import io
 
@@ -20,13 +19,14 @@ class CSVDataclass:
     """Base class that provides a "table_header" class property 
     as well as a "as_table_row()" method for simple dataclasses.dataclass.
     """
-    def table_header(self) -> Tuple[str, ...]:
+    @classmethod
+    def table_header(cls) -> Tuple[str, ...]:
         """Return the *names* from all attributes of this class.
 
         Returns:
             Tuple[str,...]: The names of the attributes for this class.
         """
-        return tuple(self.__dataclass_fields__.keys())
+        return tuple(cls.__dataclass_fields__.keys())
 
     def as_table_row(self, select_columns: Iterable[str] = None) -> Tuple[str, ...]:
         """Return the data from all attributes of this object.
@@ -49,25 +49,19 @@ class CSVDataclass:
 CSVDataclass_t = TypeVar('CSVDataclass_t', bound=CSVDataclass)
 
 class CSVReport(Generic[CSVDataclass_t]):
-    """Base class for reports that can be exported to Comma Seperated Values (CSV).
+    """Base class for reports that can be exported to Comma Separated Values (CSV).
     """
     def __init__(self, items: List[CSVDataclass_t], table_header: Tuple[str,...] = None):
         self._header: Tuple[str,...] = table_header
         self._items: List[CSVDataclass_t] = items
-    
-    @classmethod
-    def ensure_not_overriding_custom_table_header(cls, kwargs):
-        if 'table_header' in kwargs:
-            raise ValueError(f'{cls} initializer overrides the "table_header" keyword argument.')
 
-    def sort(self, sort_by: Union[str,Iterable[str]] = None):
-        """Sort this report.
+    def sort(self, *sort_by: str):
+        """Sort this report. (in-place)
 
         Args:
-            sort_by (Union[str,List[str]], optional): The column(s) to be sorted by. By default 
-                will sort over all columns, from left-to-right.
+            sort_by (Union[str,List[str]], optional): The column(s) to be sorted by. By default sort by the first column indicated by table_header.
         """
-        if sort_by is None:
+        if not sort_by:
             sort_by = self.table_header()
         self.items.sort(key=operator.attrgetter(*sort_by))
 
@@ -83,40 +77,21 @@ class CSVReport(Generic[CSVDataclass_t]):
         """
         if self._header: 
             return self._header
-        else:
-            try:
-                return self.items[0].table_header()
-            except IndexError:
-                logger.error(f'Unable to determine table header for {self}. Returning empty list.')
-                return []
+        try:
+            return self.items[0].table_header()
+        except (IndexError, AttributeError):
+            raise ValueError(f'No header provided. Unable to determine table header for {self.__class__.__name__} with data "{self.items}".')
 
-    def __iter__(self):
-        return iter(self.items)
+    def _as_tuples(self) -> List[Tuple]:
+        select_cols = self.table_header()
+        return [item.as_table_row(select_cols) for item in self.items]
 
-    def __len__(self):
-        return len(self.items)
-
-    def as_tuples(self) -> List[Tuple]:
-        return [
-            self.row_formatting(item)
-            for item in self.items
-        ]
-
-    def row_formatting(self, item: CSVDataclass_t) -> Tuple:
-        columns = self.table_header()
-        return item.as_table_row(select_columns=columns)
-
-    # TODO, should this move out of this csv module/class?
-    def as_table(self):
-        return tabulate(self.as_tuples(), self.table_header())
-
-    def as_csv(self, delim=',', override_header: Iterable[str] = None):
+    def as_csv(self, delim=',', override_header: Iterable[str] = None) -> str:
         """Produce this data structure into a CSV.
 
         Args:
             delim (str, optional): CSV delimiter to be used. Defaults to ','.
-            override_header (Iterable[str], optional): Enables overriding the default CSV header. 
-                Must be same length as this report's default `table_header`.
+            override_header (Iterable[str], optional): Enables overriding the default CSV header (labels only, cannot be used to 'select columns'). (Must be same length as this report's default `table_header`).
 
         Raises:
             ValueError: If override_header is invalid.
@@ -127,19 +102,17 @@ class CSVReport(Generic[CSVDataclass_t]):
         header = self.table_header()
         if override_header:
             if len(override_header) != len(header):
-                raise ValueError(f'''CSV header must be length: {len(header)}.
-                    Provided header length: {len(override_header)} (header: {override_header})''')
+                raise ValueError(f'''override_header must be length {len(header)}, to align with table_header: {header}. override_header length: {len(override_header)}. override_header: {override_header})''')
             header = override_header
-        return as_csv(self.as_tuples(), header, delim)
+        return as_csv(self._as_tuples(), header, delim)
 
-    def save_as_file(self, filename: str, output_directory: str = './') -> int:
+    def save_as_file(self, filename: str, output_directory: str = './', **kwargs) -> int:
         """Save this CSVReport to a file.
 
         Args:
             output_directory (str): The path where the CSV will be saved.
             filename (str): Will be used as the file name.
-            override_header (Iterable[str], optional): Enables overriding the default CSV header. 
-                Must be same length as this report's default `table_header`.
+            kwargs: Additional arguments are passed to `as_csv()` (e.g. override_header)
 
         Returns:
             int: Amount of bytes written to the file. (See `TextIOBase.write()`)
@@ -148,7 +121,7 @@ class CSVReport(Generic[CSVDataclass_t]):
         filename = _sanitize_csv_filename(filename)
         out_file_path = os.path.join(output_directory, filename)
         with open(out_file_path, 'w') as out_file:
-            return out_file.write(self.as_csv())
+            return out_file.write(self.as_csv(**kwargs))
 
 
 def as_csv(data: Iterable[Tuple], header: Iterable[str] = None, delim=',') -> str:
