@@ -8,14 +8,11 @@ from netdot.mac_address import MACAddress
 
 logger = logging.getLogger(__name__)
 
+
 @dataclass
 class PhysAddr(NetdotAPIDataclass, CSVDataclass):
-    """Represents a physical/MAC address.
-    """
-    NETDOT_TABLE_NAME = 'physaddr'
-    NETDOT_URL_PATH = 'mac'
-    NETDOT_MENU_URL_PATH = 'management'
-    # TODO Does web_url work for this class?
+    """Represents a physical/MAC address."""
+
     id: int = None
     address: MACAddress = None
     static: bool = False
@@ -23,14 +20,18 @@ class PhysAddr(NetdotAPIDataclass, CSVDataclass):
     last_seen: parse.DateTime = None
 
 
-# class physaddrattrname:
-#     id: int = None
-#     info: str = None
-#     name: str = None
+@dataclass
+class PhysAddrAttrName(NetdotAPIDataclass, CSVDataclass):
+
+    id: int = None
+    info: str = None
+    name: str = None
 
 
-# class physaddrattr:
-#     id: int = None
-#     name: int = None
-#     physaddr: int = None
-#     value: str = None
+@dataclass
+class PhysAddrAttr(NetdotAPIDataclass, CSVDataclass):
+
+    id: int = None
+    name: int = None
+    physaddr: int = None
+    value: str = None
