@@ -1,5 +1,7 @@
 from dataclasses import dataclass
+from typing import Union
 
+import netdot
 from netdot import validate
 from netdot.csv_util import CSVDataclass
 from netdot.dataclasses.base import NetdotAPIDataclass
@@ -7,13 +9,13 @@ from netdot.dataclasses.base import NetdotAPIDataclass
 
 @dataclass
 class VLAN(NetdotAPIDataclass, CSVDataclass):
-    NETDOT_MENU_URL_PATH = 'management'
-    NETDOT_TABLE_NAME = 'Vlan'
+    _NETDOT_TABLE_NAME = "Vlan"
     description: str = None
     info: str = None
     name: str = None
     vid: int = None
-    vlangroup: int = None
+    vlangroup: Union[str,'netdot.VLANGroup'] = None
+    vlangroup_xlink: int = None
 
     @property
     def has_valid_vid(self):
@@ -24,3 +26,14 @@ class VLAN(NetdotAPIDataclass, CSVDataclass):
             return True
         except ValueError:
             return False
+
+
+@dataclass
+class VLANGroup(NetdotAPIDataclass, CSVDataclass):
+    _NETDOT_TABLE_NAME = "VlanGroup"
+
+    description: str = None
+    end_vid: int = None
+    info: str = None
+    name: str = None
+    start_vid: int = None
