@@ -4,8 +4,8 @@ MAC_ADDRESS_BYTE_COUNT = 12
 
 
 class MACAddress:
-    """Represent a MAC Address, consistently.
-    """
+    """Represent a MAC Address, consistently."""
+
     def __init__(self, raw):
         self._address = self._strip_tokens(raw)
         self._validate(self._address)
@@ -17,6 +17,8 @@ class MACAddress:
         return f"MACAddress('{self._address}')"
 
     def __eq__(self, other):
+        if not isinstance(other, MACAddress):
+            return False
         return self._address.lower() == other._address.lower()
 
     def __hash__(self):
@@ -26,9 +28,9 @@ class MACAddress:
         """Get a representation of this MACAddress, formatted according to arguments.
 
         Args:
-            delimiter (str, optional): The delimiter to be used between each byte-pair in the MAC Address. 
+            delimiter (str, optional): The delimiter to be used between each byte-pair in the MAC Address.
                 E.g. '-' => aa-bb-cc-dd-ee-ff. Defaults to no delimiter.
-            lowercase (bool, optional): Ensure all alpha characters are lowercase. 
+            lowercase (bool, optional): Ensure all alpha characters are lowercase.
                 Pass `False` to ensure alpha characters are uppercase instead.
 
         Returns:
@@ -48,7 +50,7 @@ class MACAddress:
 
     @staticmethod
     def _reassemble_mac(mac_bytes, delimiter):
-        two_char_chunks = [str(mac_bytes[i:i+2]) for i in range(0, 12, 2)]
+        two_char_chunks = [str(mac_bytes[i : i + 2]) for i in range(0, 12, 2)]
         return delimiter.join(two_char_chunks)
 
     @staticmethod
@@ -62,6 +64,10 @@ class MACAddress:
             ValueError: If not a valid MAC Address.
         """
         if not mac_bytes.isalnum():
-            raise ValueError(f'Unable to parse MAC Address, invalid characters: {mac_bytes}')
+            raise ValueError(
+                f'Unable to parse MAC Address, invalid characters: {mac_bytes}'
+            )
         if len(mac_bytes) != MAC_ADDRESS_BYTE_COUNT:
-            raise ValueError(f'Unable to parse MAC Address, invalid length (expect {MAC_ADDRESS_BYTE_COUNT}, was {len(mac_bytes)}): {mac_bytes}')
+            raise ValueError(
+                f'Unable to parse MAC Address, invalid length (expect {MAC_ADDRESS_BYTE_COUNT}, was {len(mac_bytes)}): {mac_bytes}'
+            )
