@@ -24,7 +24,7 @@ logger = logging.getLogger(__name__)
 def RESTful_XML(xml):
     """This is a VERY simple parser specifically built to parse the NetDot-XML Objects.
 
-    Returns: 
+    Returns:
       Multi-level dictionary.
     """
     validate.RESTful_XML(xml)
@@ -59,19 +59,19 @@ def MACAddress_from_asset(asset: str) -> MACAddress:
     Args:
         asset (str): The asset string, of form "<Make Model>, <S/N>, <Base MAC Address>"
 
-    Example: 
+    Example:
         >>> MACAddress_from_asset("Cisco Systems (Airspace) AIR-AP1815W-B-K9, FJC25101LUN, AABBCCDDEEFF")
         MACAddress('AABBCCDDEEFF')
 
     Returns:
         MACAddress: The Base MAC Address from the asset string.
     """
-    asset_tokens = split_combined_entities_str(asset)
-    if asset == '0' or len(asset_tokens) != 3:
-        logger.warning(f'Unsure how to parse MACAddress from asset string: {asset}')
-        return None
-    raw_mac_address = split_combined_entities_str(asset)[2]
-    return MACAddress(raw_mac_address)
+    try:
+        str_tokens = asset.split(',')
+        MAC_token = str_tokens[-1].strip()
+        return MACAddress(MAC_token)
+    except Exception:
+        raise ValueError(f'Unable to parse MACAddress from asset string: {asset}')
 
 
 def DateTime(time: str) -> datetime:
@@ -85,8 +85,7 @@ def DateTime(time: str) -> datetime:
             continue
 
     EXPECTED_FORMATTING = f'datetime should be formatted as one of: {NETDOT_TIME_FORMAT_STRINGS + NETDOT_START_OF_TIME_STRINGS}'
-    raise ValueError(
-        f'Unable to parse DateTime from: {time} -- {EXPECTED_FORMATTING}')
+    raise ValueError(f'Unable to parse DateTime from: {time} -- {EXPECTED_FORMATTING}')
 
 
 def Boolean(data: str) -> bool:
@@ -105,4 +104,6 @@ def ID_from_xlink(xlink_str):
         return int(int_str)
     except IndexError:
         raise ValueError(
-            f'Unable to parse id out of xlink value: {xlink_str} -- {EXPECTED_FORMATTING}')
+            f'Unable to parse id out of xlink value: {xlink_str} -- {EXPECTED_FORMATTING}'
+        )
+
