@@ -5,10 +5,11 @@ Note: Raise an Error validation fails.
 
 import logging
 
-from netdot.exceptions import NetdotError
+from netdot import exceptions
 
 logger = logging.getLogger(__name__)
 
+
 def VLAN_id(vlan_id: int):
     # ensure: 1 <= vid <= 4094
     if vlan_id < 1 or vlan_id > 4094:
@@ -19,5 +20,7 @@ def RESTful_XML(content):
     expected_root_token = '<opt'
     xml_message = str(content)
     if expected_root_token not in xml_message:
-        logger.error(f'Expected {expected_root_token} to be root of XML response. Response: {xml_message}')
-        raise NetdotError(f'Expected {expected_root_token} to be root of XML response. Response: {xml_message[:256]}... trimmed for brevity...')
+        raise exceptions.NetdotRESTError(
+            f'Expected {expected_root_token} to be root of XML response.',
+            response=xml_message,
+        )
